exceptiontools.StaffContainmentError
====================================

.. abjad-lineage:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError

.. autoclass:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__unicode__
   :noindex:
